# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20048ResponseUsageReportHeader(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'zios_name': 'str',
        'zios_display_name': 'str',
        'upload_rate_per_gb': 'float',
        'policy_capacity_usage_cost_gbmonth': 'InlineResponse20048ResponseUsageReportHeaderPolicyCapacityUsageCostGbmonth',
        'download_rate_per_gb': 'float',
        'billing_unit': 'str',
        'total_usage_charges': 'float',
        'reporting_interval': 'InlineResponse20048ResponseUsageReportHeaderReportingInterval',
        'zios_url': 'str'
    }

    attribute_map = {
        'zios_name': 'zios_name',
        'zios_display_name': 'zios_display_name',
        'upload_rate_per_gb': 'upload_rate_per_gb',
        'policy_capacity_usage_cost_gbmonth': 'policy_capacity_usage_cost_gbmonth',
        'download_rate_per_gb': 'download_rate_per_gb',
        'billing_unit': 'billing_unit',
        'total_usage_charges': 'total_usage_charges',
        'reporting_interval': 'reporting_interval',
        'zios_url': 'zios_url'
    }

    def __init__(self, zios_name=None, zios_display_name=None, upload_rate_per_gb=None, policy_capacity_usage_cost_gbmonth=None, download_rate_per_gb=None, billing_unit=None, total_usage_charges=None, reporting_interval=None, zios_url=None, _configuration=None):  # noqa: E501
        """InlineResponse20048ResponseUsageReportHeader - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._zios_name = None
        self._zios_display_name = None
        self._upload_rate_per_gb = None
        self._policy_capacity_usage_cost_gbmonth = None
        self._download_rate_per_gb = None
        self._billing_unit = None
        self._total_usage_charges = None
        self._reporting_interval = None
        self._zios_url = None
        self.discriminator = None

        if zios_name is not None:
            self.zios_name = zios_name
        if zios_display_name is not None:
            self.zios_display_name = zios_display_name
        if upload_rate_per_gb is not None:
            self.upload_rate_per_gb = upload_rate_per_gb
        if policy_capacity_usage_cost_gbmonth is not None:
            self.policy_capacity_usage_cost_gbmonth = policy_capacity_usage_cost_gbmonth
        if download_rate_per_gb is not None:
            self.download_rate_per_gb = download_rate_per_gb
        if billing_unit is not None:
            self.billing_unit = billing_unit
        if total_usage_charges is not None:
            self.total_usage_charges = total_usage_charges
        if reporting_interval is not None:
            self.reporting_interval = reporting_interval
        if zios_url is not None:
            self.zios_url = zios_url

    @property
    def zios_name(self):
        """Gets the zios_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The zios_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: str
        """
        return self._zios_name

    @zios_name.setter
    def zios_name(self, zios_name):
        """Sets the zios_name of this InlineResponse20048ResponseUsageReportHeader.


        :param zios_name: The zios_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: str
        """

        self._zios_name = zios_name

    @property
    def zios_display_name(self):
        """Gets the zios_display_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The zios_display_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: str
        """
        return self._zios_display_name

    @zios_display_name.setter
    def zios_display_name(self, zios_display_name):
        """Sets the zios_display_name of this InlineResponse20048ResponseUsageReportHeader.


        :param zios_display_name: The zios_display_name of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: str
        """

        self._zios_display_name = zios_display_name

    @property
    def upload_rate_per_gb(self):
        """Gets the upload_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The upload_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: float
        """
        return self._upload_rate_per_gb

    @upload_rate_per_gb.setter
    def upload_rate_per_gb(self, upload_rate_per_gb):
        """Sets the upload_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.


        :param upload_rate_per_gb: The upload_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: float
        """

        self._upload_rate_per_gb = upload_rate_per_gb

    @property
    def policy_capacity_usage_cost_gbmonth(self):
        """Gets the policy_capacity_usage_cost_gbmonth of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The policy_capacity_usage_cost_gbmonth of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: InlineResponse20048ResponseUsageReportHeaderPolicyCapacityUsageCostGbmonth
        """
        return self._policy_capacity_usage_cost_gbmonth

    @policy_capacity_usage_cost_gbmonth.setter
    def policy_capacity_usage_cost_gbmonth(self, policy_capacity_usage_cost_gbmonth):
        """Sets the policy_capacity_usage_cost_gbmonth of this InlineResponse20048ResponseUsageReportHeader.


        :param policy_capacity_usage_cost_gbmonth: The policy_capacity_usage_cost_gbmonth of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: InlineResponse20048ResponseUsageReportHeaderPolicyCapacityUsageCostGbmonth
        """

        self._policy_capacity_usage_cost_gbmonth = policy_capacity_usage_cost_gbmonth

    @property
    def download_rate_per_gb(self):
        """Gets the download_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The download_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: float
        """
        return self._download_rate_per_gb

    @download_rate_per_gb.setter
    def download_rate_per_gb(self, download_rate_per_gb):
        """Sets the download_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.


        :param download_rate_per_gb: The download_rate_per_gb of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: float
        """

        self._download_rate_per_gb = download_rate_per_gb

    @property
    def billing_unit(self):
        """Gets the billing_unit of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The billing_unit of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: str
        """
        return self._billing_unit

    @billing_unit.setter
    def billing_unit(self, billing_unit):
        """Sets the billing_unit of this InlineResponse20048ResponseUsageReportHeader.


        :param billing_unit: The billing_unit of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: str
        """

        self._billing_unit = billing_unit

    @property
    def total_usage_charges(self):
        """Gets the total_usage_charges of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The total_usage_charges of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: float
        """
        return self._total_usage_charges

    @total_usage_charges.setter
    def total_usage_charges(self, total_usage_charges):
        """Sets the total_usage_charges of this InlineResponse20048ResponseUsageReportHeader.


        :param total_usage_charges: The total_usage_charges of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: float
        """

        self._total_usage_charges = total_usage_charges

    @property
    def reporting_interval(self):
        """Gets the reporting_interval of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The reporting_interval of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: InlineResponse20048ResponseUsageReportHeaderReportingInterval
        """
        return self._reporting_interval

    @reporting_interval.setter
    def reporting_interval(self, reporting_interval):
        """Sets the reporting_interval of this InlineResponse20048ResponseUsageReportHeader.


        :param reporting_interval: The reporting_interval of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: InlineResponse20048ResponseUsageReportHeaderReportingInterval
        """

        self._reporting_interval = reporting_interval

    @property
    def zios_url(self):
        """Gets the zios_url of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501


        :return: The zios_url of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :rtype: str
        """
        return self._zios_url

    @zios_url.setter
    def zios_url(self, zios_url):
        """Sets the zios_url of this InlineResponse20048ResponseUsageReportHeader.


        :param zios_url: The zios_url of this InlineResponse20048ResponseUsageReportHeader.  # noqa: E501
        :type: str
        """

        self._zios_url = zios_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20048ResponseUsageReportHeader, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20048ResponseUsageReportHeader):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20048ResponseUsageReportHeader):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class Vpsa(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allocation_zones': 'list[str]',
        'cache': 'VpsaCache',
        'app_engine': 'VpsaAppEngine',
        'status': 'str',
        'description': 'str',
        'fibre_channel': 'bool',
        'drives': 'VpsaDrives',
        'drive_count': 'int',
        'engine': 'InlineResponse20028DataEngine',
        'nova_id': 'int',
        'management_url': 'str',
        'initial_passcode': 'str',
        'ip_address': 'str',
        'id': 'int',
        'time_created_gmt': 'str',
        'name': 'str',
        'locked_down': 'bool',
        'provider': 'InlineResponse20028DataProvider',
        'product': 'str',
        'type': 'str',
        'virtual_network_interfaces': 'list[VpsaVirtualNetworkInterfaces]',
        'file_lifecycle': 'bool',
        'iscsi_dual_target': 'bool',
        'scheduled_upgrade_capable': 'bool',
        'update_available': 'bool',
        'upgrade_when': 'str',
        'upgrade_target': 'str',
        'upgrade_initiator': 'str',
        'cancel_scheduled_upgrade_capable': 'bool',
        'created_at': 'str'
    }

    attribute_map = {
        'allocation_zones': 'allocation-zones',
        'cache': 'cache',
        'app_engine': 'app_engine',
        'status': 'status',
        'description': 'description',
        'fibre_channel': 'fibre_channel',
        'drives': 'drives',
        'drive_count': 'drive_count',
        'engine': 'engine',
        'nova_id': 'nova_id',
        'management_url': 'management_url',
        'initial_passcode': 'initial_passcode',
        'ip_address': 'ip_address',
        'id': 'id',
        'time_created_gmt': 'time_created_gmt',
        'name': 'name',
        'locked_down': 'locked_down',
        'provider': 'provider',
        'product': 'product',
        'type': 'type',
        'virtual_network_interfaces': 'virtual_network_interfaces',
        'file_lifecycle': 'file_lifecycle',
        'iscsi_dual_target': 'iscsi_dual_target',
        'scheduled_upgrade_capable': 'scheduled_upgrade_capable',
        'update_available': 'update_available',
        'upgrade_when': 'upgrade_when',
        'upgrade_target': 'upgrade_target',
        'upgrade_initiator': 'upgrade_initiator',
        'cancel_scheduled_upgrade_capable': 'cancel_scheduled_upgrade_capable',
        'created_at': 'created_at'
    }

    def __init__(self, allocation_zones=None, cache=None, app_engine=None, status=None, description=None, fibre_channel=None, drives=None, drive_count=None, engine=None, nova_id=None, management_url=None, initial_passcode=None, ip_address=None, id=None, time_created_gmt=None, name=None, locked_down=None, provider=None, product=None, type=None, virtual_network_interfaces=None, file_lifecycle=None, iscsi_dual_target=None, scheduled_upgrade_capable=None, update_available=None, upgrade_when=None, upgrade_target=None, upgrade_initiator=None, cancel_scheduled_upgrade_capable=None, created_at=None, _configuration=None):  # noqa: E501
        """Vpsa - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._allocation_zones = None
        self._cache = None
        self._app_engine = None
        self._status = None
        self._description = None
        self._fibre_channel = None
        self._drives = None
        self._drive_count = None
        self._engine = None
        self._nova_id = None
        self._management_url = None
        self._initial_passcode = None
        self._ip_address = None
        self._id = None
        self._time_created_gmt = None
        self._name = None
        self._locked_down = None
        self._provider = None
        self._product = None
        self._type = None
        self._virtual_network_interfaces = None
        self._file_lifecycle = None
        self._iscsi_dual_target = None
        self._scheduled_upgrade_capable = None
        self._update_available = None
        self._upgrade_when = None
        self._upgrade_target = None
        self._upgrade_initiator = None
        self._cancel_scheduled_upgrade_capable = None
        self._created_at = None
        self.discriminator = None

        if allocation_zones is not None:
            self.allocation_zones = allocation_zones
        if cache is not None:
            self.cache = cache
        if app_engine is not None:
            self.app_engine = app_engine
        if status is not None:
            self.status = status
        if description is not None:
            self.description = description
        if fibre_channel is not None:
            self.fibre_channel = fibre_channel
        if drives is not None:
            self.drives = drives
        if drive_count is not None:
            self.drive_count = drive_count
        if engine is not None:
            self.engine = engine
        if nova_id is not None:
            self.nova_id = nova_id
        if management_url is not None:
            self.management_url = management_url
        if initial_passcode is not None:
            self.initial_passcode = initial_passcode
        if ip_address is not None:
            self.ip_address = ip_address
        if id is not None:
            self.id = id
        if time_created_gmt is not None:
            self.time_created_gmt = time_created_gmt
        if name is not None:
            self.name = name
        if locked_down is not None:
            self.locked_down = locked_down
        if provider is not None:
            self.provider = provider
        if product is not None:
            self.product = product
        if type is not None:
            self.type = type
        if virtual_network_interfaces is not None:
            self.virtual_network_interfaces = virtual_network_interfaces
        if file_lifecycle is not None:
            self.file_lifecycle = file_lifecycle
        if iscsi_dual_target is not None:
            self.iscsi_dual_target = iscsi_dual_target
        if scheduled_upgrade_capable is not None:
            self.scheduled_upgrade_capable = scheduled_upgrade_capable
        if update_available is not None:
            self.update_available = update_available
        if upgrade_when is not None:
            self.upgrade_when = upgrade_when
        if upgrade_target is not None:
            self.upgrade_target = upgrade_target
        if upgrade_initiator is not None:
            self.upgrade_initiator = upgrade_initiator
        if cancel_scheduled_upgrade_capable is not None:
            self.cancel_scheduled_upgrade_capable = cancel_scheduled_upgrade_capable
        if created_at is not None:
            self.created_at = created_at

    @property
    def allocation_zones(self):
        """Gets the allocation_zones of this Vpsa.  # noqa: E501


        :return: The allocation_zones of this Vpsa.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocation_zones

    @allocation_zones.setter
    def allocation_zones(self, allocation_zones):
        """Sets the allocation_zones of this Vpsa.


        :param allocation_zones: The allocation_zones of this Vpsa.  # noqa: E501
        :type: list[str]
        """

        self._allocation_zones = allocation_zones

    @property
    def cache(self):
        """Gets the cache of this Vpsa.  # noqa: E501


        :return: The cache of this Vpsa.  # noqa: E501
        :rtype: VpsaCache
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this Vpsa.


        :param cache: The cache of this Vpsa.  # noqa: E501
        :type: VpsaCache
        """

        self._cache = cache

    @property
    def app_engine(self):
        """Gets the app_engine of this Vpsa.  # noqa: E501


        :return: The app_engine of this Vpsa.  # noqa: E501
        :rtype: VpsaAppEngine
        """
        return self._app_engine

    @app_engine.setter
    def app_engine(self, app_engine):
        """Sets the app_engine of this Vpsa.


        :param app_engine: The app_engine of this Vpsa.  # noqa: E501
        :type: VpsaAppEngine
        """

        self._app_engine = app_engine

    @property
    def status(self):
        """Gets the status of this Vpsa.  # noqa: E501


        :return: The status of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Vpsa.


        :param status: The status of this Vpsa.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def description(self):
        """Gets the description of this Vpsa.  # noqa: E501


        :return: The description of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Vpsa.


        :param description: The description of this Vpsa.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def fibre_channel(self):
        """Gets the fibre_channel of this Vpsa.  # noqa: E501


        :return: The fibre_channel of this Vpsa.  # noqa: E501
        :rtype: bool
        """
        return self._fibre_channel

    @fibre_channel.setter
    def fibre_channel(self, fibre_channel):
        """Sets the fibre_channel of this Vpsa.


        :param fibre_channel: The fibre_channel of this Vpsa.  # noqa: E501
        :type: bool
        """

        self._fibre_channel = fibre_channel

    @property
    def drives(self):
        """Gets the drives of this Vpsa.  # noqa: E501


        :return: The drives of this Vpsa.  # noqa: E501
        :rtype: VpsaDrives
        """
        return self._drives

    @drives.setter
    def drives(self, drives):
        """Sets the drives of this Vpsa.


        :param drives: The drives of this Vpsa.  # noqa: E501
        :type: VpsaDrives
        """

        self._drives = drives

    @property
    def drive_count(self):
        """Gets the drive_count of this Vpsa.  # noqa: E501


        :return: The drive_count of this Vpsa.  # noqa: E501
        :rtype: int
        """
        return self._drive_count

    @drive_count.setter
    def drive_count(self, drive_count):
        """Sets the drive_count of this Vpsa.


        :param drive_count: The drive_count of this Vpsa.  # noqa: E501
        :type: int
        """

        self._drive_count = drive_count

    @property
    def engine(self):
        """Gets the engine of this Vpsa.  # noqa: E501


        :return: The engine of this Vpsa.  # noqa: E501
        :rtype: InlineResponse20028DataEngine
        """
        return self._engine

    @engine.setter
    def engine(self, engine):
        """Sets the engine of this Vpsa.


        :param engine: The engine of this Vpsa.  # noqa: E501
        :type: InlineResponse20028DataEngine
        """

        self._engine = engine

    @property
    def nova_id(self):
        """Gets the nova_id of this Vpsa.  # noqa: E501


        :return: The nova_id of this Vpsa.  # noqa: E501
        :rtype: int
        """
        return self._nova_id

    @nova_id.setter
    def nova_id(self, nova_id):
        """Sets the nova_id of this Vpsa.


        :param nova_id: The nova_id of this Vpsa.  # noqa: E501
        :type: int
        """

        self._nova_id = nova_id

    @property
    def management_url(self):
        """Gets the management_url of this Vpsa.  # noqa: E501


        :return: The management_url of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._management_url

    @management_url.setter
    def management_url(self, management_url):
        """Sets the management_url of this Vpsa.


        :param management_url: The management_url of this Vpsa.  # noqa: E501
        :type: str
        """

        self._management_url = management_url

    @property
    def initial_passcode(self):
        """Gets the initial_passcode of this Vpsa.  # noqa: E501


        :return: The initial_passcode of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._initial_passcode

    @initial_passcode.setter
    def initial_passcode(self, initial_passcode):
        """Sets the initial_passcode of this Vpsa.


        :param initial_passcode: The initial_passcode of this Vpsa.  # noqa: E501
        :type: str
        """

        self._initial_passcode = initial_passcode

    @property
    def ip_address(self):
        """Gets the ip_address of this Vpsa.  # noqa: E501


        :return: The ip_address of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this Vpsa.


        :param ip_address: The ip_address of this Vpsa.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def id(self):
        """Gets the id of this Vpsa.  # noqa: E501


        :return: The id of this Vpsa.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Vpsa.


        :param id: The id of this Vpsa.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def time_created_gmt(self):
        """Gets the time_created_gmt of this Vpsa.  # noqa: E501


        :return: The time_created_gmt of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._time_created_gmt

    @time_created_gmt.setter
    def time_created_gmt(self, time_created_gmt):
        """Sets the time_created_gmt of this Vpsa.


        :param time_created_gmt: The time_created_gmt of this Vpsa.  # noqa: E501
        :type: str
        """

        self._time_created_gmt = time_created_gmt

    @property
    def name(self):
        """Gets the name of this Vpsa.  # noqa: E501


        :return: The name of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Vpsa.


        :param name: The name of this Vpsa.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def locked_down(self):
        """Gets the locked_down of this Vpsa.  # noqa: E501


        :return: The locked_down of this Vpsa.  # noqa: E501
        :rtype: bool
        """
        return self._locked_down

    @locked_down.setter
    def locked_down(self, locked_down):
        """Sets the locked_down of this Vpsa.


        :param locked_down: The locked_down of this Vpsa.  # noqa: E501
        :type: bool
        """

        self._locked_down = locked_down

    @property
    def provider(self):
        """Gets the provider of this Vpsa.  # noqa: E501


        :return: The provider of this Vpsa.  # noqa: E501
        :rtype: InlineResponse20028DataProvider
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this Vpsa.


        :param provider: The provider of this Vpsa.  # noqa: E501
        :type: InlineResponse20028DataProvider
        """

        self._provider = provider

    @property
    def product(self):
        """Gets the product of this Vpsa.  # noqa: E501


        :return: The product of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this Vpsa.


        :param product: The product of this Vpsa.  # noqa: E501
        :type: str
        """

        self._product = product

    @property
    def type(self):
        """Gets the type of this Vpsa.  # noqa: E501


        :return: The type of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Vpsa.


        :param type: The type of this Vpsa.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def virtual_network_interfaces(self):
        """Gets the virtual_network_interfaces of this Vpsa.  # noqa: E501


        :return: The virtual_network_interfaces of this Vpsa.  # noqa: E501
        :rtype: list[VpsaVirtualNetworkInterfaces]
        """
        return self._virtual_network_interfaces

    @virtual_network_interfaces.setter
    def virtual_network_interfaces(self, virtual_network_interfaces):
        """Sets the virtual_network_interfaces of this Vpsa.


        :param virtual_network_interfaces: The virtual_network_interfaces of this Vpsa.  # noqa: E501
        :type: list[VpsaVirtualNetworkInterfaces]
        """

        self._virtual_network_interfaces = virtual_network_interfaces

    @property
    def file_lifecycle(self):
        """Gets the file_lifecycle of this Vpsa.  # noqa: E501


        :return: The file_lifecycle of this Vpsa.  # noqa: E501
        :rtype: bool
        """
        return self._file_lifecycle

    @file_lifecycle.setter
    def file_lifecycle(self, file_lifecycle):
        """Sets the file_lifecycle of this Vpsa.


        :param file_lifecycle: The file_lifecycle of this Vpsa.  # noqa: E501
        :type: bool
        """

        self._file_lifecycle = file_lifecycle

    @property
    def iscsi_dual_target(self):
        """Gets the iscsi_dual_target of this Vpsa.  # noqa: E501


        :return: The iscsi_dual_target of this Vpsa.  # noqa: E501
        :rtype: bool
        """
        return self._iscsi_dual_target

    @iscsi_dual_target.setter
    def iscsi_dual_target(self, iscsi_dual_target):
        """Sets the iscsi_dual_target of this Vpsa.


        :param iscsi_dual_target: The iscsi_dual_target of this Vpsa.  # noqa: E501
        :type: bool
        """

        self._iscsi_dual_target = iscsi_dual_target

    @property
    def scheduled_upgrade_capable(self):
        """Gets the scheduled_upgrade_capable of this Vpsa.  # noqa: E501


        :return: The scheduled_upgrade_capable of this Vpsa.  # noqa: E501
        :rtype: bool
        """
        return self._scheduled_upgrade_capable

    @scheduled_upgrade_capable.setter
    def scheduled_upgrade_capable(self, scheduled_upgrade_capable):
        """Sets the scheduled_upgrade_capable of this Vpsa.


        :param scheduled_upgrade_capable: The scheduled_upgrade_capable of this Vpsa.  # noqa: E501
        :type: bool
        """

        self._scheduled_upgrade_capable = scheduled_upgrade_capable

    @property
    def update_available(self):
        """Gets the update_available of this Vpsa.  # noqa: E501


        :return: The update_available of this Vpsa.  # noqa: E501
        :rtype: bool
        """
        return self._update_available

    @update_available.setter
    def update_available(self, update_available):
        """Sets the update_available of this Vpsa.


        :param update_available: The update_available of this Vpsa.  # noqa: E501
        :type: bool
        """

        self._update_available = update_available

    @property
    def upgrade_when(self):
        """Gets the upgrade_when of this Vpsa.  # noqa: E501

        When the VPSA software version is scheduled to be upgraded. \"now\" means immediate upgrade. \"manual\" means upgrade will occur after resume. Or a scheduled time when the upgrade will apply.  # noqa: E501

        :return: The upgrade_when of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._upgrade_when

    @upgrade_when.setter
    def upgrade_when(self, upgrade_when):
        """Sets the upgrade_when of this Vpsa.

        When the VPSA software version is scheduled to be upgraded. \"now\" means immediate upgrade. \"manual\" means upgrade will occur after resume. Or a scheduled time when the upgrade will apply.  # noqa: E501

        :param upgrade_when: The upgrade_when of this Vpsa.  # noqa: E501
        :type: str
        """

        self._upgrade_when = upgrade_when

    @property
    def upgrade_target(self):
        """Gets the upgrade_target of this Vpsa.  # noqa: E501

        VPSA software upgrade target version  # noqa: E501

        :return: The upgrade_target of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._upgrade_target

    @upgrade_target.setter
    def upgrade_target(self, upgrade_target):
        """Sets the upgrade_target of this Vpsa.

        VPSA software upgrade target version  # noqa: E501

        :param upgrade_target: The upgrade_target of this Vpsa.  # noqa: E501
        :type: str
        """

        self._upgrade_target = upgrade_target

    @property
    def upgrade_initiator(self):
        """Gets the upgrade_initiator of this Vpsa.  # noqa: E501

        VPSA software upgrade initiator, \"cc\" represents Command Center user, \"pp\" represents Provisioning Portal user.  # noqa: E501

        :return: The upgrade_initiator of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._upgrade_initiator

    @upgrade_initiator.setter
    def upgrade_initiator(self, upgrade_initiator):
        """Sets the upgrade_initiator of this Vpsa.

        VPSA software upgrade initiator, \"cc\" represents Command Center user, \"pp\" represents Provisioning Portal user.  # noqa: E501

        :param upgrade_initiator: The upgrade_initiator of this Vpsa.  # noqa: E501
        :type: str
        """

        self._upgrade_initiator = upgrade_initiator

    @property
    def cancel_scheduled_upgrade_capable(self):
        """Gets the cancel_scheduled_upgrade_capable of this Vpsa.  # noqa: E501

        VPSA capable of processing cancellation of scheduled software version upgrade.  # noqa: E501

        :return: The cancel_scheduled_upgrade_capable of this Vpsa.  # noqa: E501
        :rtype: bool
        """
        return self._cancel_scheduled_upgrade_capable

    @cancel_scheduled_upgrade_capable.setter
    def cancel_scheduled_upgrade_capable(self, cancel_scheduled_upgrade_capable):
        """Sets the cancel_scheduled_upgrade_capable of this Vpsa.

        VPSA capable of processing cancellation of scheduled software version upgrade.  # noqa: E501

        :param cancel_scheduled_upgrade_capable: The cancel_scheduled_upgrade_capable of this Vpsa.  # noqa: E501
        :type: bool
        """

        self._cancel_scheduled_upgrade_capable = cancel_scheduled_upgrade_capable

    @property
    def created_at(self):
        """Gets the created_at of this Vpsa.  # noqa: E501


        :return: The created_at of this Vpsa.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Vpsa.


        :param created_at: The created_at of this Vpsa.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Vpsa, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Vpsa):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Vpsa):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class CloudTestConnection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloud_id': 'int',
        'ip': 'str',
        'admin_user': 'str',
        'admin_key': 'str',
        'auth_url': 'str',
        'nova_url': 'str',
        'keystone_url': 'str',
        'ssl_verify': 'bool',
        'gateway_address': 'str'
    }

    attribute_map = {
        'cloud_id': 'cloud_id',
        'ip': 'ip',
        'admin_user': 'admin_user',
        'admin_key': 'admin_key',
        'auth_url': 'auth_url',
        'nova_url': 'nova_url',
        'keystone_url': 'keystone_url',
        'ssl_verify': 'ssl_verify',
        'gateway_address': 'gateway_address'
    }

    def __init__(self, cloud_id=None, ip=None, admin_user=None, admin_key=None, auth_url=None, nova_url=None, keystone_url=None, ssl_verify=None, gateway_address=None, _configuration=None):  # noqa: E501
        """CloudTestConnection - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cloud_id = None
        self._ip = None
        self._admin_user = None
        self._admin_key = None
        self._auth_url = None
        self._nova_url = None
        self._keystone_url = None
        self._ssl_verify = None
        self._gateway_address = None
        self.discriminator = None

        if cloud_id is not None:
            self.cloud_id = cloud_id
        if ip is not None:
            self.ip = ip
        if admin_user is not None:
            self.admin_user = admin_user
        if admin_key is not None:
            self.admin_key = admin_key
        if auth_url is not None:
            self.auth_url = auth_url
        if nova_url is not None:
            self.nova_url = nova_url
        if keystone_url is not None:
            self.keystone_url = keystone_url
        if ssl_verify is not None:
            self.ssl_verify = ssl_verify
        if gateway_address is not None:
            self.gateway_address = gateway_address

    @property
    def cloud_id(self):
        """Gets the cloud_id of this CloudTestConnection.  # noqa: E501

        Cloud ID. Opt out for testing new cloud connectivity.  # noqa: E501

        :return: The cloud_id of this CloudTestConnection.  # noqa: E501
        :rtype: int
        """
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, cloud_id):
        """Sets the cloud_id of this CloudTestConnection.

        Cloud ID. Opt out for testing new cloud connectivity.  # noqa: E501

        :param cloud_id: The cloud_id of this CloudTestConnection.  # noqa: E501
        :type: int
        """

        self._cloud_id = cloud_id

    @property
    def ip(self):
        """Gets the ip of this CloudTestConnection.  # noqa: E501

        Cloud's ip address  # noqa: E501

        :return: The ip of this CloudTestConnection.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this CloudTestConnection.

        Cloud's ip address  # noqa: E501

        :param ip: The ip of this CloudTestConnection.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def admin_user(self):
        """Gets the admin_user of this CloudTestConnection.  # noqa: E501

        Nova admin user  # noqa: E501

        :return: The admin_user of this CloudTestConnection.  # noqa: E501
        :rtype: str
        """
        return self._admin_user

    @admin_user.setter
    def admin_user(self, admin_user):
        """Sets the admin_user of this CloudTestConnection.

        Nova admin user  # noqa: E501

        :param admin_user: The admin_user of this CloudTestConnection.  # noqa: E501
        :type: str
        """

        self._admin_user = admin_user

    @property
    def admin_key(self):
        """Gets the admin_key of this CloudTestConnection.  # noqa: E501

        Nova admin key. Only applies to new cloud. Do not provide for existing cloud.  # noqa: E501

        :return: The admin_key of this CloudTestConnection.  # noqa: E501
        :rtype: str
        """
        return self._admin_key

    @admin_key.setter
    def admin_key(self, admin_key):
        """Sets the admin_key of this CloudTestConnection.

        Nova admin key. Only applies to new cloud. Do not provide for existing cloud.  # noqa: E501

        :param admin_key: The admin_key of this CloudTestConnection.  # noqa: E501
        :type: str
        """

        self._admin_key = admin_key

    @property
    def auth_url(self):
        """Gets the auth_url of this CloudTestConnection.  # noqa: E501

        Auth URL.  # noqa: E501

        :return: The auth_url of this CloudTestConnection.  # noqa: E501
        :rtype: str
        """
        return self._auth_url

    @auth_url.setter
    def auth_url(self, auth_url):
        """Sets the auth_url of this CloudTestConnection.

        Auth URL.  # noqa: E501

        :param auth_url: The auth_url of this CloudTestConnection.  # noqa: E501
        :type: str
        """

        self._auth_url = auth_url

    @property
    def nova_url(self):
        """Gets the nova_url of this CloudTestConnection.  # noqa: E501

        Nova URL.  # noqa: E501

        :return: The nova_url of this CloudTestConnection.  # noqa: E501
        :rtype: str
        """
        return self._nova_url

    @nova_url.setter
    def nova_url(self, nova_url):
        """Sets the nova_url of this CloudTestConnection.

        Nova URL.  # noqa: E501

        :param nova_url: The nova_url of this CloudTestConnection.  # noqa: E501
        :type: str
        """

        self._nova_url = nova_url

    @property
    def keystone_url(self):
        """Gets the keystone_url of this CloudTestConnection.  # noqa: E501

        Keystone URL.  # noqa: E501

        :return: The keystone_url of this CloudTestConnection.  # noqa: E501
        :rtype: str
        """
        return self._keystone_url

    @keystone_url.setter
    def keystone_url(self, keystone_url):
        """Sets the keystone_url of this CloudTestConnection.

        Keystone URL.  # noqa: E501

        :param keystone_url: The keystone_url of this CloudTestConnection.  # noqa: E501
        :type: str
        """

        self._keystone_url = keystone_url

    @property
    def ssl_verify(self):
        """Gets the ssl_verify of this CloudTestConnection.  # noqa: E501

        Verify SSL (public ecommerce only).  # noqa: E501

        :return: The ssl_verify of this CloudTestConnection.  # noqa: E501
        :rtype: bool
        """
        return self._ssl_verify

    @ssl_verify.setter
    def ssl_verify(self, ssl_verify):
        """Sets the ssl_verify of this CloudTestConnection.

        Verify SSL (public ecommerce only).  # noqa: E501

        :param ssl_verify: The ssl_verify of this CloudTestConnection.  # noqa: E501
        :type: bool
        """

        self._ssl_verify = ssl_verify

    @property
    def gateway_address(self):
        """Gets the gateway_address of this CloudTestConnection.  # noqa: E501

        Gateway Address.  # noqa: E501

        :return: The gateway_address of this CloudTestConnection.  # noqa: E501
        :rtype: str
        """
        return self._gateway_address

    @gateway_address.setter
    def gateway_address(self, gateway_address):
        """Sets the gateway_address of this CloudTestConnection.

        Gateway Address.  # noqa: E501

        :param gateway_address: The gateway_address of this CloudTestConnection.  # noqa: E501
        :type: str
        """

        self._gateway_address = gateway_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudTestConnection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudTestConnection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CloudTestConnection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class UpdateVpsaGenericZconfigKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key_name': 'str',
        'key_value': 'str'
    }

    attribute_map = {
        'key_name': 'key_name',
        'key_value': 'key_value'
    }

    def __init__(self, key_name=None, key_value=None, _configuration=None):  # noqa: E501
        """UpdateVpsaGenericZconfigKey - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._key_name = None
        self._key_value = None
        self.discriminator = None

        self.key_name = key_name
        self.key_value = key_value

    @property
    def key_name(self):
        """Gets the key_name of this UpdateVpsaGenericZconfigKey.  # noqa: E501

        Key name  # noqa: E501

        :return: The key_name of this UpdateVpsaGenericZconfigKey.  # noqa: E501
        :rtype: str
        """
        return self._key_name

    @key_name.setter
    def key_name(self, key_name):
        """Sets the key_name of this UpdateVpsaGenericZconfigKey.

        Key name  # noqa: E501

        :param key_name: The key_name of this UpdateVpsaGenericZconfigKey.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and key_name is None:
            raise ValueError("Invalid value for `key_name`, must not be `None`")  # noqa: E501

        self._key_name = key_name

    @property
    def key_value(self):
        """Gets the key_value of this UpdateVpsaGenericZconfigKey.  # noqa: E501

        Key value  # noqa: E501

        :return: The key_value of this UpdateVpsaGenericZconfigKey.  # noqa: E501
        :rtype: str
        """
        return self._key_value

    @key_value.setter
    def key_value(self, key_value):
        """Sets the key_value of this UpdateVpsaGenericZconfigKey.

        Key value  # noqa: E501

        :param key_value: The key_value of this UpdateVpsaGenericZconfigKey.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and key_value is None:
            raise ValueError("Invalid value for `key_value`, must not be `None`")  # noqa: E501

        self._key_value = key_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateVpsaGenericZconfigKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVpsaGenericZconfigKey):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateVpsaGenericZconfigKey):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import io
import json
import logging
import re
import ssl

import certifi
# python 2 and python 3 compatibility library
import six
from six.moves.urllib.parse import urlencode

try:
    import urllib3
except ImportError:
    raise ImportError('Swagger python client requires urllib3.')


logger = logging.getLogger(__name__)


class RESTResponse(io.IOBase):

    def __init__(self, resp):
        self.urllib3_response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = resp.data

    def getheaders(self):
        """Returns a dictionary of the response headers."""
        return self.urllib3_response.headers

    def getheader(self, name, default=None):
        """Returns a given response header."""
        return self.urllib3_response.headers.get(name, default)


class RESTClientObject(object):

    def __init__(self, configuration, pools_size=4, maxsize=None):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # maxsize is the number of requests to host that are allowed in parallel  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        # ca_certs
        if configuration.ssl_ca_cert:
            ca_certs = configuration.ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        addition_pool_args = {}
        if configuration.assert_hostname is not None:
            addition_pool_args['assert_hostname'] = configuration.assert_hostname  # noqa: E501

        if maxsize is None:
            if configuration.connection_pool_maxsize is not None:
                maxsize = configuration.connection_pool_maxsize
            else:
                maxsize = 4

        # https pool manager
        if configuration.proxy:
            self.pool_manager = urllib3.ProxyManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                proxy_url=configuration.proxy,
                **addition_pool_args
            )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                **addition_pool_args
            )

    def request(self, method, url, query_params=None, headers=None,
                body=None, post_params=None, _preload_content=True,
                _request_timeout=None):
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param query_params: query parameters in the url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencoded`
                            and `multipart/form-data`
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT',
                          'PATCH', 'OPTIONS']

        if post_params and body:
            raise ValueError(
                "body parameter cannot be used with post_params parameter."
            )

        post_params = post_params or {}
        headers = headers or {}

        timeout = None
        if _request_timeout:
            if isinstance(_request_timeout, (int, ) if six.PY3 else (int, long)):  # noqa: E501,F821
                timeout = urllib3.Timeout(total=_request_timeout)
            elif (isinstance(_request_timeout, tuple) and
                  len(_request_timeout) == 2):
                timeout = urllib3.Timeout(
                    connect=_request_timeout[0], read=_request_timeout[1])

        if 'Content-Type' not in headers:
            headers['Content-Type'] = 'application/json'

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
                if query_params:
                    url += '?' + urlencode(query_params)
                if re.search('json', headers['Content-Type'], re.IGNORECASE):
                    request_body = '{}'
                    if body is not None:
                        request_body = json.dumps(body)
                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'application/x-www-form-urlencoded':  # noqa: E501
                    r = self.pool_manager.request(
                        method, url,
                        fields=post_params,
                        encode_multipart=False,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers['Content-Type']
                    r = self.pool_manager.request(
                        method, url,
                        fields=post_params,
                        encode_multipart=True,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is
                # provided in serialized form
                elif isinstance(body, str):
                    request_body = body
                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url,
                                              fields=query_params,
                                              preload_content=_preload_content,
                                              timeout=timeout,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        if _preload_content:
            r = RESTResponse(r)

            # In the python 3, the response.data is bytes.
            # we need to decode it to string.
            if six.PY3:
                r.data = r.data.decode('utf8')

            # log response body
            logger.debug("response body: %s", r.data)

        if not 200 <= r.status <= 299:
            raise ApiException(http_resp=r)

        return r

    def GET(self, url, headers=None, query_params=None, _preload_content=True,
            _request_timeout=None):
        return self.request("GET", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def HEAD(self, url, headers=None, query_params=None, _preload_content=True,
             _request_timeout=None):
        return self.request("HEAD", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def OPTIONS(self, url, headers=None, query_params=None, post_params=None,
                body=None, _preload_content=True, _request_timeout=None):
        return self.request("OPTIONS", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def DELETE(self, url, headers=None, query_params=None, body=None,
               _preload_content=True, _request_timeout=None):
        return self.request("DELETE", url,
                            headers=headers,
                            query_params=query_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def POST(self, url, headers=None, query_params=None, post_params=None,
             body=None, _preload_content=True, _request_timeout=None):
        return self.request("POST", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PUT(self, url, headers=None, query_params=None, post_params=None,
            body=None, _preload_content=True, _request_timeout=None):
        return self.request("PUT", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PATCH(self, url, headers=None, query_params=None, post_params=None,
              body=None, _preload_content=True, _request_timeout=None):
        return self.request("PATCH", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)


class ApiException(Exception):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(
                self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20052ResponseImage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'status': 'str',
        'is_layered': 'str',
        'docker_id': 'str',
        'license_state': 'int',
        'capacity_mb': 'int',
        'repository': 'str',
        'tag': 'str',
        'volume_id': 'int',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'status': 'status',
        'is_layered': 'is_layered',
        'docker_id': 'docker_id',
        'license_state': 'license_state',
        'capacity_mb': 'capacity_mb',
        'repository': 'repository',
        'tag': 'tag',
        'volume_id': 'volume_id',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, display_name=None, status=None, is_layered=None, docker_id=None, license_state=None, capacity_mb=None, repository=None, tag=None, volume_id=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20052ResponseImage - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._status = None
        self._is_layered = None
        self._docker_id = None
        self._license_state = None
        self._capacity_mb = None
        self._repository = None
        self._tag = None
        self._volume_id = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if status is not None:
            self.status = status
        if is_layered is not None:
            self.is_layered = is_layered
        if docker_id is not None:
            self.docker_id = docker_id
        if license_state is not None:
            self.license_state = license_state
        if capacity_mb is not None:
            self.capacity_mb = capacity_mb
        if repository is not None:
            self.repository = repository
        if tag is not None:
            self.tag = tag
        if volume_id is not None:
            self.volume_id = volume_id
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The name of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20052ResponseImage.


        :param name: The name of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The display_name of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20052ResponseImage.


        :param display_name: The display_name of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def status(self):
        """Gets the status of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The status of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20052ResponseImage.


        :param status: The status of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def is_layered(self):
        """Gets the is_layered of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The is_layered of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._is_layered

    @is_layered.setter
    def is_layered(self, is_layered):
        """Sets the is_layered of this InlineResponse20052ResponseImage.


        :param is_layered: The is_layered of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._is_layered = is_layered

    @property
    def docker_id(self):
        """Gets the docker_id of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The docker_id of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._docker_id

    @docker_id.setter
    def docker_id(self, docker_id):
        """Sets the docker_id of this InlineResponse20052ResponseImage.


        :param docker_id: The docker_id of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._docker_id = docker_id

    @property
    def license_state(self):
        """Gets the license_state of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The license_state of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: int
        """
        return self._license_state

    @license_state.setter
    def license_state(self, license_state):
        """Sets the license_state of this InlineResponse20052ResponseImage.


        :param license_state: The license_state of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: int
        """

        self._license_state = license_state

    @property
    def capacity_mb(self):
        """Gets the capacity_mb of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The capacity_mb of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: int
        """
        return self._capacity_mb

    @capacity_mb.setter
    def capacity_mb(self, capacity_mb):
        """Sets the capacity_mb of this InlineResponse20052ResponseImage.


        :param capacity_mb: The capacity_mb of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: int
        """

        self._capacity_mb = capacity_mb

    @property
    def repository(self):
        """Gets the repository of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The repository of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this InlineResponse20052ResponseImage.


        :param repository: The repository of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._repository = repository

    @property
    def tag(self):
        """Gets the tag of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The tag of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this InlineResponse20052ResponseImage.


        :param tag: The tag of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def volume_id(self):
        """Gets the volume_id of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The volume_id of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: int
        """
        return self._volume_id

    @volume_id.setter
    def volume_id(self, volume_id):
        """Sets the volume_id of this InlineResponse20052ResponseImage.


        :param volume_id: The volume_id of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: int
        """

        self._volume_id = volume_id

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The created_at of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20052ResponseImage.


        :param created_at: The created_at of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20052ResponseImage.  # noqa: E501


        :return: The modified_at of this InlineResponse20052ResponseImage.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20052ResponseImage.


        :param modified_at: The modified_at of this InlineResponse20052ResponseImage.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20052ResponseImage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20052ResponseImage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20052ResponseImage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20029ResponseDisk(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'disk_type': 'str',
        'disk_uuid': 'str',
        'storage_node': 'str',
        'vpartition_id': 'int',
        'raid_group_name': 'str',
        'usage': 'str',
        'status': 'str',
        'capacity': 'int',
        'disk_capacity': 'int',
        'allocation_group': 'str',
        'cache': 'str',
        'allocation_zone': 'str',
        'allocation_zone_display_name': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'meta_data': 'str',
        'setup_on_ssd': 'str',
        'flc': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'disk_type': 'disk_type',
        'disk_uuid': 'disk_uuid',
        'storage_node': 'storage_node',
        'vpartition_id': 'vpartition_id',
        'raid_group_name': 'raid_group_name',
        'usage': 'usage',
        'status': 'status',
        'capacity': 'capacity',
        'disk_capacity': 'disk_capacity',
        'allocation_group': 'allocation_group',
        'cache': 'cache',
        'allocation_zone': 'allocation_zone',
        'allocation_zone_display_name': 'allocation_zone_display_name',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'meta_data': 'meta_data',
        'setup_on_ssd': 'setup_on_ssd',
        'flc': 'flc'
    }

    def __init__(self, name=None, display_name=None, disk_type=None, disk_uuid=None, storage_node=None, vpartition_id=None, raid_group_name=None, usage=None, status=None, capacity=None, disk_capacity=None, allocation_group=None, cache=None, allocation_zone=None, allocation_zone_display_name=None, created_at=None, modified_at=None, meta_data=None, setup_on_ssd=None, flc=None, _configuration=None):  # noqa: E501
        """InlineResponse20029ResponseDisk - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._disk_type = None
        self._disk_uuid = None
        self._storage_node = None
        self._vpartition_id = None
        self._raid_group_name = None
        self._usage = None
        self._status = None
        self._capacity = None
        self._disk_capacity = None
        self._allocation_group = None
        self._cache = None
        self._allocation_zone = None
        self._allocation_zone_display_name = None
        self._created_at = None
        self._modified_at = None
        self._meta_data = None
        self._setup_on_ssd = None
        self._flc = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if disk_type is not None:
            self.disk_type = disk_type
        if disk_uuid is not None:
            self.disk_uuid = disk_uuid
        if storage_node is not None:
            self.storage_node = storage_node
        if vpartition_id is not None:
            self.vpartition_id = vpartition_id
        if raid_group_name is not None:
            self.raid_group_name = raid_group_name
        if usage is not None:
            self.usage = usage
        if status is not None:
            self.status = status
        if capacity is not None:
            self.capacity = capacity
        if disk_capacity is not None:
            self.disk_capacity = disk_capacity
        if allocation_group is not None:
            self.allocation_group = allocation_group
        if cache is not None:
            self.cache = cache
        if allocation_zone is not None:
            self.allocation_zone = allocation_zone
        if allocation_zone_display_name is not None:
            self.allocation_zone_display_name = allocation_zone_display_name
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if meta_data is not None:
            self.meta_data = meta_data
        if setup_on_ssd is not None:
            self.setup_on_ssd = setup_on_ssd
        if flc is not None:
            self.flc = flc

    @property
    def name(self):
        """Gets the name of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The name of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20029ResponseDisk.


        :param name: The name of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The display_name of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20029ResponseDisk.


        :param display_name: The display_name of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def disk_type(self):
        """Gets the disk_type of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The disk_type of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._disk_type

    @disk_type.setter
    def disk_type(self, disk_type):
        """Sets the disk_type of this InlineResponse20029ResponseDisk.


        :param disk_type: The disk_type of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._disk_type = disk_type

    @property
    def disk_uuid(self):
        """Gets the disk_uuid of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The disk_uuid of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._disk_uuid

    @disk_uuid.setter
    def disk_uuid(self, disk_uuid):
        """Sets the disk_uuid of this InlineResponse20029ResponseDisk.


        :param disk_uuid: The disk_uuid of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._disk_uuid = disk_uuid

    @property
    def storage_node(self):
        """Gets the storage_node of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The storage_node of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._storage_node

    @storage_node.setter
    def storage_node(self, storage_node):
        """Sets the storage_node of this InlineResponse20029ResponseDisk.


        :param storage_node: The storage_node of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._storage_node = storage_node

    @property
    def vpartition_id(self):
        """Gets the vpartition_id of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The vpartition_id of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._vpartition_id

    @vpartition_id.setter
    def vpartition_id(self, vpartition_id):
        """Sets the vpartition_id of this InlineResponse20029ResponseDisk.


        :param vpartition_id: The vpartition_id of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: int
        """

        self._vpartition_id = vpartition_id

    @property
    def raid_group_name(self):
        """Gets the raid_group_name of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The raid_group_name of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._raid_group_name

    @raid_group_name.setter
    def raid_group_name(self, raid_group_name):
        """Sets the raid_group_name of this InlineResponse20029ResponseDisk.


        :param raid_group_name: The raid_group_name of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._raid_group_name = raid_group_name

    @property
    def usage(self):
        """Gets the usage of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The usage of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """Sets the usage of this InlineResponse20029ResponseDisk.


        :param usage: The usage of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._usage = usage

    @property
    def status(self):
        """Gets the status of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The status of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20029ResponseDisk.


        :param status: The status of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def capacity(self):
        """Gets the capacity of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The capacity of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this InlineResponse20029ResponseDisk.


        :param capacity: The capacity of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def disk_capacity(self):
        """Gets the disk_capacity of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The disk_capacity of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: int
        """
        return self._disk_capacity

    @disk_capacity.setter
    def disk_capacity(self, disk_capacity):
        """Sets the disk_capacity of this InlineResponse20029ResponseDisk.


        :param disk_capacity: The disk_capacity of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: int
        """

        self._disk_capacity = disk_capacity

    @property
    def allocation_group(self):
        """Gets the allocation_group of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The allocation_group of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._allocation_group

    @allocation_group.setter
    def allocation_group(self, allocation_group):
        """Sets the allocation_group of this InlineResponse20029ResponseDisk.


        :param allocation_group: The allocation_group of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._allocation_group = allocation_group

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The cache of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20029ResponseDisk.


        :param cache: The cache of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._cache = cache

    @property
    def allocation_zone(self):
        """Gets the allocation_zone of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The allocation_zone of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone

    @allocation_zone.setter
    def allocation_zone(self, allocation_zone):
        """Sets the allocation_zone of this InlineResponse20029ResponseDisk.


        :param allocation_zone: The allocation_zone of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._allocation_zone = allocation_zone

    @property
    def allocation_zone_display_name(self):
        """Gets the allocation_zone_display_name of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The allocation_zone_display_name of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone_display_name

    @allocation_zone_display_name.setter
    def allocation_zone_display_name(self, allocation_zone_display_name):
        """Sets the allocation_zone_display_name of this InlineResponse20029ResponseDisk.


        :param allocation_zone_display_name: The allocation_zone_display_name of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._allocation_zone_display_name = allocation_zone_display_name

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The created_at of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20029ResponseDisk.


        :param created_at: The created_at of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The modified_at of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20029ResponseDisk.


        :param modified_at: The modified_at of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def meta_data(self):
        """Gets the meta_data of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The meta_data of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """Sets the meta_data of this InlineResponse20029ResponseDisk.


        :param meta_data: The meta_data of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._meta_data = meta_data

    @property
    def setup_on_ssd(self):
        """Gets the setup_on_ssd of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The setup_on_ssd of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._setup_on_ssd

    @setup_on_ssd.setter
    def setup_on_ssd(self, setup_on_ssd):
        """Sets the setup_on_ssd of this InlineResponse20029ResponseDisk.


        :param setup_on_ssd: The setup_on_ssd of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._setup_on_ssd = setup_on_ssd

    @property
    def flc(self):
        """Gets the flc of this InlineResponse20029ResponseDisk.  # noqa: E501


        :return: The flc of this InlineResponse20029ResponseDisk.  # noqa: E501
        :rtype: str
        """
        return self._flc

    @flc.setter
    def flc(self, flc):
        """Sets the flc of this InlineResponse20029ResponseDisk.


        :param flc: The flc of this InlineResponse20029ResponseDisk.  # noqa: E501
        :type: str
        """

        self._flc = flc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20029ResponseDisk, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20029ResponseDisk):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20029ResponseDisk):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200252ResponseMigrationJob(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'src_cg_display_name': 'str',
        'src_cg_name': 'str',
        'src_pool_display_name': 'str',
        'dst_cg_name': 'str',
        'dst_pool_display_name': 'str',
        'shipping_display_name': 'str',
        'status': 'str',
        'cur_sync_rate_kb_sec': 'int',
        'shipping_position_mb': 'int',
        'total_capacity_to_migrate_mb': 'int',
        'already_migrated_mb': 'int',
        'remaining_time_seconds': 'int',
        'created_at': 'str',
        'modified_at': 'str',
        'limited_higher_rate_in_kbs': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'src_cg_display_name': 'src_cg_display_name',
        'src_cg_name': 'src_cg_name',
        'src_pool_display_name': 'src_pool_display_name',
        'dst_cg_name': 'dst_cg_name',
        'dst_pool_display_name': 'dst_pool_display_name',
        'shipping_display_name': 'shipping_display_name',
        'status': 'status',
        'cur_sync_rate_kb_sec': 'cur_sync_rate_kb_sec',
        'shipping_position_mb': 'shipping_position_mb',
        'total_capacity_to_migrate_mb': 'total_capacity_to_migrate_mb',
        'already_migrated_mb': 'already_migrated_mb',
        'remaining_time_seconds': 'remaining_time_seconds',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'limited_higher_rate_in_kbs': 'limited_higher_rate_in_KBS'
    }

    def __init__(self, name=None, display_name=None, src_cg_display_name=None, src_cg_name=None, src_pool_display_name=None, dst_cg_name=None, dst_pool_display_name=None, shipping_display_name=None, status=None, cur_sync_rate_kb_sec=None, shipping_position_mb=None, total_capacity_to_migrate_mb=None, already_migrated_mb=None, remaining_time_seconds=None, created_at=None, modified_at=None, limited_higher_rate_in_kbs=None, _configuration=None):  # noqa: E501
        """InlineResponse200252ResponseMigrationJob - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._src_cg_display_name = None
        self._src_cg_name = None
        self._src_pool_display_name = None
        self._dst_cg_name = None
        self._dst_pool_display_name = None
        self._shipping_display_name = None
        self._status = None
        self._cur_sync_rate_kb_sec = None
        self._shipping_position_mb = None
        self._total_capacity_to_migrate_mb = None
        self._already_migrated_mb = None
        self._remaining_time_seconds = None
        self._created_at = None
        self._modified_at = None
        self._limited_higher_rate_in_kbs = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if src_cg_display_name is not None:
            self.src_cg_display_name = src_cg_display_name
        if src_cg_name is not None:
            self.src_cg_name = src_cg_name
        if src_pool_display_name is not None:
            self.src_pool_display_name = src_pool_display_name
        if dst_cg_name is not None:
            self.dst_cg_name = dst_cg_name
        if dst_pool_display_name is not None:
            self.dst_pool_display_name = dst_pool_display_name
        if shipping_display_name is not None:
            self.shipping_display_name = shipping_display_name
        if status is not None:
            self.status = status
        if cur_sync_rate_kb_sec is not None:
            self.cur_sync_rate_kb_sec = cur_sync_rate_kb_sec
        if shipping_position_mb is not None:
            self.shipping_position_mb = shipping_position_mb
        if total_capacity_to_migrate_mb is not None:
            self.total_capacity_to_migrate_mb = total_capacity_to_migrate_mb
        if already_migrated_mb is not None:
            self.already_migrated_mb = already_migrated_mb
        if remaining_time_seconds is not None:
            self.remaining_time_seconds = remaining_time_seconds
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if limited_higher_rate_in_kbs is not None:
            self.limited_higher_rate_in_kbs = limited_higher_rate_in_kbs

    @property
    def name(self):
        """Gets the name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200252ResponseMigrationJob.


        :param name: The name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200252ResponseMigrationJob.


        :param display_name: The display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def src_cg_display_name(self):
        """Gets the src_cg_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The src_cg_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._src_cg_display_name

    @src_cg_display_name.setter
    def src_cg_display_name(self, src_cg_display_name):
        """Sets the src_cg_display_name of this InlineResponse200252ResponseMigrationJob.


        :param src_cg_display_name: The src_cg_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._src_cg_display_name = src_cg_display_name

    @property
    def src_cg_name(self):
        """Gets the src_cg_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The src_cg_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._src_cg_name

    @src_cg_name.setter
    def src_cg_name(self, src_cg_name):
        """Sets the src_cg_name of this InlineResponse200252ResponseMigrationJob.


        :param src_cg_name: The src_cg_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._src_cg_name = src_cg_name

    @property
    def src_pool_display_name(self):
        """Gets the src_pool_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The src_pool_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._src_pool_display_name

    @src_pool_display_name.setter
    def src_pool_display_name(self, src_pool_display_name):
        """Sets the src_pool_display_name of this InlineResponse200252ResponseMigrationJob.


        :param src_pool_display_name: The src_pool_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._src_pool_display_name = src_pool_display_name

    @property
    def dst_cg_name(self):
        """Gets the dst_cg_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The dst_cg_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._dst_cg_name

    @dst_cg_name.setter
    def dst_cg_name(self, dst_cg_name):
        """Sets the dst_cg_name of this InlineResponse200252ResponseMigrationJob.


        :param dst_cg_name: The dst_cg_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._dst_cg_name = dst_cg_name

    @property
    def dst_pool_display_name(self):
        """Gets the dst_pool_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The dst_pool_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._dst_pool_display_name

    @dst_pool_display_name.setter
    def dst_pool_display_name(self, dst_pool_display_name):
        """Sets the dst_pool_display_name of this InlineResponse200252ResponseMigrationJob.


        :param dst_pool_display_name: The dst_pool_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._dst_pool_display_name = dst_pool_display_name

    @property
    def shipping_display_name(self):
        """Gets the shipping_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The shipping_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._shipping_display_name

    @shipping_display_name.setter
    def shipping_display_name(self, shipping_display_name):
        """Sets the shipping_display_name of this InlineResponse200252ResponseMigrationJob.


        :param shipping_display_name: The shipping_display_name of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._shipping_display_name = shipping_display_name

    @property
    def status(self):
        """Gets the status of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The status of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200252ResponseMigrationJob.


        :param status: The status of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def cur_sync_rate_kb_sec(self):
        """Gets the cur_sync_rate_kb_sec of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The cur_sync_rate_kb_sec of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: int
        """
        return self._cur_sync_rate_kb_sec

    @cur_sync_rate_kb_sec.setter
    def cur_sync_rate_kb_sec(self, cur_sync_rate_kb_sec):
        """Sets the cur_sync_rate_kb_sec of this InlineResponse200252ResponseMigrationJob.


        :param cur_sync_rate_kb_sec: The cur_sync_rate_kb_sec of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: int
        """

        self._cur_sync_rate_kb_sec = cur_sync_rate_kb_sec

    @property
    def shipping_position_mb(self):
        """Gets the shipping_position_mb of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The shipping_position_mb of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: int
        """
        return self._shipping_position_mb

    @shipping_position_mb.setter
    def shipping_position_mb(self, shipping_position_mb):
        """Sets the shipping_position_mb of this InlineResponse200252ResponseMigrationJob.


        :param shipping_position_mb: The shipping_position_mb of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: int
        """

        self._shipping_position_mb = shipping_position_mb

    @property
    def total_capacity_to_migrate_mb(self):
        """Gets the total_capacity_to_migrate_mb of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The total_capacity_to_migrate_mb of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: int
        """
        return self._total_capacity_to_migrate_mb

    @total_capacity_to_migrate_mb.setter
    def total_capacity_to_migrate_mb(self, total_capacity_to_migrate_mb):
        """Sets the total_capacity_to_migrate_mb of this InlineResponse200252ResponseMigrationJob.


        :param total_capacity_to_migrate_mb: The total_capacity_to_migrate_mb of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: int
        """

        self._total_capacity_to_migrate_mb = total_capacity_to_migrate_mb

    @property
    def already_migrated_mb(self):
        """Gets the already_migrated_mb of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The already_migrated_mb of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: int
        """
        return self._already_migrated_mb

    @already_migrated_mb.setter
    def already_migrated_mb(self, already_migrated_mb):
        """Sets the already_migrated_mb of this InlineResponse200252ResponseMigrationJob.


        :param already_migrated_mb: The already_migrated_mb of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: int
        """

        self._already_migrated_mb = already_migrated_mb

    @property
    def remaining_time_seconds(self):
        """Gets the remaining_time_seconds of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The remaining_time_seconds of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: int
        """
        return self._remaining_time_seconds

    @remaining_time_seconds.setter
    def remaining_time_seconds(self, remaining_time_seconds):
        """Sets the remaining_time_seconds of this InlineResponse200252ResponseMigrationJob.


        :param remaining_time_seconds: The remaining_time_seconds of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: int
        """

        self._remaining_time_seconds = remaining_time_seconds

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The created_at of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200252ResponseMigrationJob.


        :param created_at: The created_at of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200252ResponseMigrationJob.  # noqa: E501


        :return: The modified_at of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200252ResponseMigrationJob.


        :param modified_at: The modified_at of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def limited_higher_rate_in_kbs(self):
        """Gets the limited_higher_rate_in_kbs of this InlineResponse200252ResponseMigrationJob.  # noqa: E501

        Migration job rate limit in KiB/sec. Zero means rate limiting is disabled.  # noqa: E501

        :return: The limited_higher_rate_in_kbs of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :rtype: str
        """
        return self._limited_higher_rate_in_kbs

    @limited_higher_rate_in_kbs.setter
    def limited_higher_rate_in_kbs(self, limited_higher_rate_in_kbs):
        """Sets the limited_higher_rate_in_kbs of this InlineResponse200252ResponseMigrationJob.

        Migration job rate limit in KiB/sec. Zero means rate limiting is disabled.  # noqa: E501

        :param limited_higher_rate_in_kbs: The limited_higher_rate_in_kbs of this InlineResponse200252ResponseMigrationJob.  # noqa: E501
        :type: str
        """

        self._limited_higher_rate_in_kbs = limited_higher_rate_in_kbs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200252ResponseMigrationJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200252ResponseMigrationJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200252ResponseMigrationJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200276ResponseVsa(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'int',
        'url': 'str',
        'display_name': 'str',
        'service_mode': 'int',
        'version': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'snapshot_creation_overload_protection': 'str',
        'create_server_on_login': 'str'
    }

    attribute_map = {
        'name': 'name',
        'url': 'url',
        'display_name': 'display_name',
        'service_mode': 'service_mode',
        'version': 'version',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'snapshot_creation_overload_protection': 'snapshot_creation_overload_protection',
        'create_server_on_login': 'create_server_on_login'
    }

    def __init__(self, name=None, url=None, display_name=None, service_mode=None, version=None, created_at=None, modified_at=None, snapshot_creation_overload_protection=None, create_server_on_login=None, _configuration=None):  # noqa: E501
        """InlineResponse200276ResponseVsa - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._url = None
        self._display_name = None
        self._service_mode = None
        self._version = None
        self._created_at = None
        self._modified_at = None
        self._snapshot_creation_overload_protection = None
        self._create_server_on_login = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if url is not None:
            self.url = url
        if display_name is not None:
            self.display_name = display_name
        if service_mode is not None:
            self.service_mode = service_mode
        if version is not None:
            self.version = version
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if snapshot_creation_overload_protection is not None:
            self.snapshot_creation_overload_protection = snapshot_creation_overload_protection
        if create_server_on_login is not None:
            self.create_server_on_login = create_server_on_login

    @property
    def name(self):
        """Gets the name of this InlineResponse200276ResponseVsa.  # noqa: E501


        :return: The name of this InlineResponse200276ResponseVsa.  # noqa: E501
        :rtype: int
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200276ResponseVsa.


        :param name: The name of this InlineResponse200276ResponseVsa.  # noqa: E501
        :type: int
        """

        self._name = name

    @property
    def url(self):
        """Gets the url of this InlineResponse200276ResponseVsa.  # noqa: E501


        :return: The url of this InlineResponse200276ResponseVsa.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this InlineResponse200276ResponseVsa.


        :param url: The url of this InlineResponse200276ResponseVsa.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200276ResponseVsa.  # noqa: E501


        :return: The display_name of this InlineResponse200276ResponseVsa.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200276ResponseVsa.


        :param display_name: The display_name of this InlineResponse200276ResponseVsa.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def service_mode(self):
        """Gets the service_mode of this InlineResponse200276ResponseVsa.  # noqa: E501


        :return: The service_mode of this InlineResponse200276ResponseVsa.  # noqa: E501
        :rtype: int
        """
        return self._service_mode

    @service_mode.setter
    def service_mode(self, service_mode):
        """Sets the service_mode of this InlineResponse200276ResponseVsa.


        :param service_mode: The service_mode of this InlineResponse200276ResponseVsa.  # noqa: E501
        :type: int
        """

        self._service_mode = service_mode

    @property
    def version(self):
        """Gets the version of this InlineResponse200276ResponseVsa.  # noqa: E501


        :return: The version of this InlineResponse200276ResponseVsa.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InlineResponse200276ResponseVsa.


        :param version: The version of this InlineResponse200276ResponseVsa.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200276ResponseVsa.  # noqa: E501


        :return: The created_at of this InlineResponse200276ResponseVsa.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200276ResponseVsa.


        :param created_at: The created_at of this InlineResponse200276ResponseVsa.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200276ResponseVsa.  # noqa: E501


        :return: The modified_at of this InlineResponse200276ResponseVsa.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200276ResponseVsa.


        :param modified_at: The modified_at of this InlineResponse200276ResponseVsa.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def snapshot_creation_overload_protection(self):
        """Gets the snapshot_creation_overload_protection of this InlineResponse200276ResponseVsa.  # noqa: E501


        :return: The snapshot_creation_overload_protection of this InlineResponse200276ResponseVsa.  # noqa: E501
        :rtype: str
        """
        return self._snapshot_creation_overload_protection

    @snapshot_creation_overload_protection.setter
    def snapshot_creation_overload_protection(self, snapshot_creation_overload_protection):
        """Sets the snapshot_creation_overload_protection of this InlineResponse200276ResponseVsa.


        :param snapshot_creation_overload_protection: The snapshot_creation_overload_protection of this InlineResponse200276ResponseVsa.  # noqa: E501
        :type: str
        """

        self._snapshot_creation_overload_protection = snapshot_creation_overload_protection

    @property
    def create_server_on_login(self):
        """Gets the create_server_on_login of this InlineResponse200276ResponseVsa.  # noqa: E501


        :return: The create_server_on_login of this InlineResponse200276ResponseVsa.  # noqa: E501
        :rtype: str
        """
        return self._create_server_on_login

    @create_server_on_login.setter
    def create_server_on_login(self, create_server_on_login):
        """Sets the create_server_on_login of this InlineResponse200276ResponseVsa.


        :param create_server_on_login: The create_server_on_login of this InlineResponse200276ResponseVsa.  # noqa: E501
        :type: str
        """

        self._create_server_on_login = create_server_on_login

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200276ResponseVsa, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200276ResponseVsa):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200276ResponseVsa):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.09-sp2
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class CloudEngineTypes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'hourly_price_usd': 'str',
        'name': 'str',
        'max_drives': 'int',
        'max_cache_gb': 'int',
        'key': 'str',
        'encryption_hourly_price_usd': 'str',
        'specs': 'str',
        'cache': 'CloudCache'
    }

    attribute_map = {
        'id': 'id',
        'hourly_price_usd': 'hourly_price_usd',
        'name': 'name',
        'max_drives': 'max_drives',
        'max_cache_gb': 'max_cache_gb',
        'key': 'key',
        'encryption_hourly_price_usd': 'encryption_hourly_price_usd',
        'specs': 'specs',
        'cache': 'cache'
    }

    def __init__(self, id=None, hourly_price_usd=None, name=None, max_drives=None, max_cache_gb=None, key=None, encryption_hourly_price_usd=None, specs=None, cache=None, _configuration=None):  # noqa: E501
        """CloudEngineTypes - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._hourly_price_usd = None
        self._name = None
        self._max_drives = None
        self._max_cache_gb = None
        self._key = None
        self._encryption_hourly_price_usd = None
        self._specs = None
        self._cache = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if hourly_price_usd is not None:
            self.hourly_price_usd = hourly_price_usd
        if name is not None:
            self.name = name
        if max_drives is not None:
            self.max_drives = max_drives
        if max_cache_gb is not None:
            self.max_cache_gb = max_cache_gb
        if key is not None:
            self.key = key
        if encryption_hourly_price_usd is not None:
            self.encryption_hourly_price_usd = encryption_hourly_price_usd
        if specs is not None:
            self.specs = specs
        if cache is not None:
            self.cache = cache

    @property
    def id(self):
        """Gets the id of this CloudEngineTypes.  # noqa: E501


        :return: The id of this CloudEngineTypes.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CloudEngineTypes.


        :param id: The id of this CloudEngineTypes.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def hourly_price_usd(self):
        """Gets the hourly_price_usd of this CloudEngineTypes.  # noqa: E501


        :return: The hourly_price_usd of this CloudEngineTypes.  # noqa: E501
        :rtype: str
        """
        return self._hourly_price_usd

    @hourly_price_usd.setter
    def hourly_price_usd(self, hourly_price_usd):
        """Sets the hourly_price_usd of this CloudEngineTypes.


        :param hourly_price_usd: The hourly_price_usd of this CloudEngineTypes.  # noqa: E501
        :type: str
        """

        self._hourly_price_usd = hourly_price_usd

    @property
    def name(self):
        """Gets the name of this CloudEngineTypes.  # noqa: E501


        :return: The name of this CloudEngineTypes.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CloudEngineTypes.


        :param name: The name of this CloudEngineTypes.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def max_drives(self):
        """Gets the max_drives of this CloudEngineTypes.  # noqa: E501


        :return: The max_drives of this CloudEngineTypes.  # noqa: E501
        :rtype: int
        """
        return self._max_drives

    @max_drives.setter
    def max_drives(self, max_drives):
        """Sets the max_drives of this CloudEngineTypes.


        :param max_drives: The max_drives of this CloudEngineTypes.  # noqa: E501
        :type: int
        """

        self._max_drives = max_drives

    @property
    def max_cache_gb(self):
        """Gets the max_cache_gb of this CloudEngineTypes.  # noqa: E501


        :return: The max_cache_gb of this CloudEngineTypes.  # noqa: E501
        :rtype: int
        """
        return self._max_cache_gb

    @max_cache_gb.setter
    def max_cache_gb(self, max_cache_gb):
        """Sets the max_cache_gb of this CloudEngineTypes.


        :param max_cache_gb: The max_cache_gb of this CloudEngineTypes.  # noqa: E501
        :type: int
        """

        self._max_cache_gb = max_cache_gb

    @property
    def key(self):
        """Gets the key of this CloudEngineTypes.  # noqa: E501


        :return: The key of this CloudEngineTypes.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this CloudEngineTypes.


        :param key: The key of this CloudEngineTypes.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def encryption_hourly_price_usd(self):
        """Gets the encryption_hourly_price_usd of this CloudEngineTypes.  # noqa: E501


        :return: The encryption_hourly_price_usd of this CloudEngineTypes.  # noqa: E501
        :rtype: str
        """
        return self._encryption_hourly_price_usd

    @encryption_hourly_price_usd.setter
    def encryption_hourly_price_usd(self, encryption_hourly_price_usd):
        """Sets the encryption_hourly_price_usd of this CloudEngineTypes.


        :param encryption_hourly_price_usd: The encryption_hourly_price_usd of this CloudEngineTypes.  # noqa: E501
        :type: str
        """

        self._encryption_hourly_price_usd = encryption_hourly_price_usd

    @property
    def specs(self):
        """Gets the specs of this CloudEngineTypes.  # noqa: E501


        :return: The specs of this CloudEngineTypes.  # noqa: E501
        :rtype: str
        """
        return self._specs

    @specs.setter
    def specs(self, specs):
        """Sets the specs of this CloudEngineTypes.


        :param specs: The specs of this CloudEngineTypes.  # noqa: E501
        :type: str
        """

        self._specs = specs

    @property
    def cache(self):
        """Gets the cache of this CloudEngineTypes.  # noqa: E501


        :return: The cache of this CloudEngineTypes.  # noqa: E501
        :rtype: CloudCache
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this CloudEngineTypes.


        :param cache: The cache of this CloudEngineTypes.  # noqa: E501
        :type: CloudCache
        """

        self._cache = cache

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudEngineTypes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudEngineTypes):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CloudEngineTypes):
            return True

        return self.to_dict() != other.to_dict()
